==> pyabaqus-1.0.3-py2.py3-none-any.whl: abaqus/Material/Gap/GapRadiation.py <==
class GapRadiation:
    """The GapRadiation object specifies radiative heat transfer between closely adjacent
    surfaces. 

    Access
    ------
        - import material
        - mdb.models[name].materials[name].gapRadiation
        - import odbMaterial
        - session.odbs[name].materials[name].gapRadiation

    Table Data
    ----------
        - Effective view factor.
        - Gap clearance.
        - Repeat this data line as often as necessary to define the dependence of the view factor on gap clearance.

    Corresponding analysis keywords
    -------------------------------
        - GAP RADIATION

    """

    def __init__(self, mainSurfaceEmissivity: float, secondarySurfaceEmissivity: float, table: tuple):
        """This method creates a GapRadiation object.

        Path
        ----
            - mdb.models[name].materials[name].Gapradiation
            - session.odbs[name].materials[name].Gapradiation

        Parameters
        ----------
        mainSurfaceEmissivity
            A Float specifying the Emissivity of main surface.ϵA 
        secondarySurfaceEmissivity
            A Float specifying the Emissivity of the secondary surfaceϵB. 
        table
            A sequence of sequences of Floats specifying the items described below. 

        Returns
        -------
            A Gapradiation object. 

        Exceptions
        ----------
            None. 
        """
        pass

    def setValues(self):
        """This method modifies the GapRadiation object.

        Parameters
        ----------

        Returns
        -------
            None. 

        Exceptions
        ----------
            None. 
        """
        pass

==> pyabaqus-1.0.5-py2.py3-none-any.whl: abaqus/Material/Gap/GapRadiation.py <==
class GapRadiation:
    """The GapRadiation object specifies radiative heat transfer between closely adjacent
    surfaces. 

    Access
    ------
        - import material
        - mdb.models[name].materials[name].gapRadiation
        - import odbMaterial
        - session.odbs[name].materials[name].gapRadiation

    Table Data
    ----------
        - Effective view factor.
        - Gap clearance.
        - Repeat this data line as often as necessary to define the dependence of the view factor on gap clearance.

    Corresponding analysis keywords
    -------------------------------
        - GAP RADIATION

    """

    def __init__(self, mainSurfaceEmissivity: float, secondarySurfaceEmissivity: float, table: tuple):
        """This method creates a GapRadiation object.

        Path
        ----
            - mdb.models[name].materials[name].Gapradiation
            - session.odbs[name].materials[name].Gapradiation

        Parameters
        ----------
        mainSurfaceEmissivity
            A Float specifying the Emissivity of main surface.ϵA 
        secondarySurfaceEmissivity
            A Float specifying the Emissivity of the secondary surfaceϵB. 
        table
            A sequence of sequences of Floats specifying the items described below. 

        Returns
        -------
            A Gapradiation object. . 
        """
        pass

    def setValues(self):
        """This method modifies the GapRadiation object.

        Parameters
        ----------
        """
        pass
